For usage details, check the `Wiki`_!
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

If you still need support, please post on the `Maniacal Labs User Group`_
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

For easy hardware interfacing, check out the BiblioPixel supported
`AllPixel`_.

Do you have an animation you would like to share? Submit to our
`animation repository`_ or post it to `our Maniacal Labs User Group`_.

Overview
========

BiblioPixel is a pure Python 3 library for programming light animations.
It provides an easy to use, cross-platform, and completely output
agnostic framework that greatly eases designing and programming
animations for a wide variety of displays.

In the current form, it is designed specifically for displays comprised
of LED strips, but there are no real limits on what the output device
can be, due to the output driver model.

See the documentation in the `Wiki`_ for more detailed information.

.. _Wiki: https://github.com/ManiacalLabs/BiblioPixel/wiki
.. _Maniacal Labs User Group: https://groups.google.com/d/forum/maniacal-labs-users
.. _AllPixel: http://maniacallabs.com/AllPixel
.. _animation repository: https://github.com/ManiacalLabs/BiblioPixelAnimations
.. _our Maniacal Labs User Group: https://groups.google.com/d/forum/maniacal-labs-users
